<?php
/**
 * Recent Section options
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */

// Add Recent section
$wp_customize->add_section( 'mega_blog_pro_recent_section', array(
	'title'             => esc_html__( 'Recent Posts','mega-blog-pro' ),
	'description'       => esc_html__( 'Recent Section options.', 'mega-blog-pro' ),
	'panel'             => 'mega_blog_pro_front_page_panel',
) );

// Recent content enable control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[recent_section_enable]', array(
	'default'			=> 	$options['recent_section_enable'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Switch_Control( $wp_customize, 'mega_blog_pro_theme_options[recent_section_enable]', array(
	'label'             => esc_html__( 'Recent Section Enable', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'on_off_label' 		=> mega_blog_pro_switch_options(),
) ) );

// Recent us title setting and control
$wp_customize->add_setting( 'mega_blog_pro_theme_options[recent_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['recent_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[recent_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-blog-pro' ),
	'section'        	=> 'mega_blog_pro_recent_section',
	'active_callback' 	=> 'mega_blog_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_blog_pro_theme_options[recent_title]', array(
		'selector'            => '#recent-posts .wrapper .site-main .section-header h2.section-title',
		'settings'            => 'mega_blog_pro_theme_options[recent_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_blog_pro_recent_title_partial',
    ) );
}

// Recent us content type control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[recent_content_type]', array(
	'default'          	=> $options['recent_content_type'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[recent_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_blog_pro_is_recent_section_enable',
	'choices'			=> array( 
		'category' 	=> esc_html__( 'Category', 'mega-blog-pro' ),
		'recent' 	=> esc_html__( 'Recent Posts', 'mega-blog-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[recent_count]', array(
	'default'          	=> $options['recent_count'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_number_range',
	'validate_callback' => 'mega_blog_pro_validate_recent_count',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[recent_count]', array(
	'label'             => esc_html__( 'Number of Recent Posts', 'mega-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'active_callback'   => 'mega_blog_pro_is_recent_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_blog_pro_theme_options[recent_content_category]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_blog_pro_theme_options[recent_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_blog_pro_is_recent_section_content_category_enable'
) ) );

// recent posts description control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[recent_content_recent]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Note_Control( $wp_customize, 'mega_blog_pro_theme_options[recent_content_recent]', array(
	'label'             => esc_html__( 'Display recent posts.', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'active_callback'	=> 'mega_blog_pro_is_recent_section_content_recent_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_blog_pro_theme_options[recent_exclude_category]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Category_Control( $wp_customize,'mega_blog_pro_theme_options[recent_exclude_category]', array(
	'label'             => esc_html__( 'Exclude Categories', 'mega-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Press SHIFT key and select multiple categories. Posts from selected categories will be excluded.', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_recent_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_blog_pro_is_recent_section_content_recent_enable'
) ) );